| Title: | Data from Access to Information Law |
|---|---|
| Description: | Downloads the public data available from the Brazilian Access to Information Law and and performs a search on information requests and appeals made since 2015. |
| Authors: | Igor Laltuf [aut, cre] (ORCID: <https://orcid.org/0000-0002-5614-4404>) |
| Maintainer: | Igor Laltuf <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.5.2 |
| Built: | 2026-05-24 09:33:37 UTC |
| Source: | https://github.com/igorlaltuf/dail |
Downloads data for the selected years, apply a filter and return it in the form of a dataframe.
appeals(year = "all", agency = "all", search = "all", answer = F)appeals(year = "all", agency = "all", search = "all", answer = F)
year |
selects the years which data will be downloaded. integer. |
agency |
selects the public agency to be searched. see the available agencies in agencies_initials. character. |
search |
selects the keyword to be searched. character. |
answer |
if true, fetches the content of the search argument in the appeals responses. boolean. |
a dataframe with appeals containing the keyword
## Not run: appeals(search = 'PAC')## Not run: appeals(search = 'PAC')
Downloads data from 2002 to 2022 and return it in the form of a dataframe. Deflated values refer to values in November 2022.
corporateCardExpenses()corporateCardExpenses()
a dataframe with the data from 2002 to 2022.
## Not run: df <- corporateCardExpenses()## Not run: df <- corporateCardExpenses()
Downloads data for the selected years, apply a filter and return it in the form of a dataframe.
requests(year = "all", agency = "all", search = "all", answer = F)requests(year = "all", agency = "all", search = "all", answer = F)
year |
selects the years which data will be downloaded. integer. |
agency |
selects the public agency to be searched. see the available agencies in agencies_initials. character. |
search |
selects the keyword to be searched. character. |
answer |
if true, fetches the content of the search argument in the request responses. boolean. |
a dataframe with requests containing the keyword
## Not run: requests(search = 'PAC')## Not run: requests(search = 'PAC')